import setuptools

with open("README.md", "r") as fh:
    desc = fh.read()
    
setuptools.setup(
    name="UgwayK_test_package", # Replace with your own username
    version="0.0.1",
    author="UgwayK",
    author_email="nuang0530@naver.com",
    description="A small example package",
    long_description=desc,
    long_description_content_type="text/markdown",
    url="https://blog.naver.com/nuang0530",
    packages=setuptools.find_packages(),
    python_requires='>=3.6'
)


from ugwayk.module import UgkSetDefault 

class UgkCalc(UgkSetDefault):
    def reset_all(self):
        # 계산기 초기화
        self.start_num = 0
    
    def plus(self, end_num, value_store = True):
        # 덧셈하는 구간
        retsult = self.start_num + end_num
        if value_store:
            # 결과값을 저장한 후로 연산을 이어가고 싶을 경우
            self.start_num = retsult
        return retsult
    
    def diff(self, end_num, value_store = True):
        retsult = self.start_num - end_num
        if value_store:
            # 결과값을 저장한 후로 연산을 이어가고 싶을 경우
            self.start_num = retsult
        return retsult
    
    def mult(self, end_num, value_store = True):
        retsult = self.start_num * end_num
        if value_store:
            # 결과값을 저장한 후로 연산을 이어가고 싶을 경우
            self.start_num = retsult
        return retsult
    
    def divide(self, end_num, value_store = True):
        if end_num == 0:
            raise ValueError("end_num cannot be 0")
        retsult = self.start_num / end_num
        if value_store:
            # 결과값을 저장한 후로 연산을 이어가고 싶을 경우
            self.start_num = retsult
        return retsult
    
    
    